@@ -11,7 +11,9 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Apple_Make] = "Apple";
   makes[Beko_Make] = "Beko";
   makes[Bose_Make] = "Bose";
+  makes[Bush_Make] = "Bush";
   makes[Cambridge_Make] = "Cambridge Audio";
+  makes[Canon_Make] = "Canon";
   makes[Daewoo_Make] = "Daewoo";
   makes[Denon_Make] = "Denon";
   makes[DigitalStream_Make] = "Digital Stream";
@@ -20,6 +22,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Ei_Make] = "Ei";
   makes[Elgato_Make] = "Elgato";
   makes[Emerson_Make] = "Emerson";
+  makes[Epson_Make] = "Epson";
   makes[Fortec_Make] = "Fortec Star";
   makes[GoldStar_Make] = "GoldStar";
   makes[Grundig_Make] = "Grundig";
@@ -29,6 +32,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Homecast_Make] = "Homecast";
   makes[HP_Make] = "HP";
   makes[Huawei_Make] = "Huawei";
+  makes[Humax_Make] = "Humax";
   makes[JVC_Make] = "JVC";
   makes[Kenwood_Make] = "Kenwood";
   makes[LG_Make] = "LG";
@@ -54,9 +58,11 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Sharp_Make] = "Sharp";
   makes[Sky_Make] = "Sky";
   makes[Sony_Make] = "Sony";
+  makes[Technics_Make] = "Technics";
   makes[Tivo_Make] = "TiVo";
   makes[Topfield_Make] = "Topfield";
   makes[Toshiba_Make] = "Toshiba";
+  makes[United_Make] = "United";
   makes[Vestel_Make] = "Vestel";
   makes[Virgin_Make] = "Virgin Media";
   makes[Vizio_Make] = "Vizio";
