@@ -12,7 +12,9 @@ enum PIRMakeName{
   Apple_Make,
   Beko_Make,
   Bose_Make,
+  Bush_Make,
   Cambridge_Make,
+  Canon_Make,
   Daewoo_Make,
   Denon_Make,
   DigitalStream_Make,
@@ -21,6 +23,7 @@ enum PIRMakeName{
   Ei_Make,
   Elgato_Make,
   Emerson_Make,
+  Epson_Make,
   Fortec_Make,
   GoldStar_Make,
   Grundig_Make,
@@ -30,6 +33,7 @@ enum PIRMakeName{
   Homecast_Make,
   HP_Make,
   Huawei_Make,
+  Humax_Make,
   JVC_Make,
   Kenwood_Make,
   LG_Make,
@@ -55,9 +59,11 @@ enum PIRMakeName{
   Sharp_Make,
   Sky_Make,
   Sony_Make,
+  Technics_Make,
   Tivo_Make,
   Topfield_Make,
   Toshiba_Make,
+  United_Make,
   Vestel_Make,
   Virgin_Make,
   Vizio_Make,
